@@ -29,10 +29,14 @@
 
 #include "../modes/normal.h"
 #include "../objects/circle.h"
+#include "../objects/conic.h"
+#include "../objects/coniclines.h"
+#include "../objects/conicsextra.h"
 #include "../objects/segment.h"
 #include "../objects/normalpoint.h"
 #include "../objects/midpoint.h"
 #include "../objects/line.h"
+#include "../objects/radicallines.h"
 #include "../objects/macro.h"
 #include "../objects/label.h"
 #include "../objects/intersection.h"
@@ -41,6 +45,7 @@
 #include "../objects/translatedpoint.h"
 #include "../objects/mirrorpoint.h"
 #include "../objects/ray.h"
+#include "../objects/coordproppoint.h"
 #include "../objects/rotatedpoint.h"
 #include "../objects/arc.h"
 #include "../misc/type.h"
@@ -174,24 +179,39 @@ void KigDocument::setupTypes()
   if ( Object::types().empty() )
   {
     Object::addBuiltinType( new TStdType<Segment> );
+    Object::addBuiltinType( new TMultiType<LineConicAsymptotes> );
+    Object::addBuiltinType( new TStdType<ConicBAAP> );
+    Object::addBuiltinType( new TStdType<ConicBDFP> );
     Object::addBuiltinType( new TStdType<RotatedPoint> );
     Object::addBuiltinType( new TStdType<LineTTP> );
     Object::addBuiltinType( new TStdType<LinePerpend> );
     Object::addBuiltinType( new TStdType<LineParallel> );
     Object::addBuiltinType( new TStdType<LineRadical> );
+    Object::addBuiltinType( new TMultiType<LineConicRadical> );
     Object::addBuiltinType( new TStdType<CircleBCP> );
     Object::addBuiltinType( new TStdType<CircleBTP> );
+    Object::addBuiltinType( new TStdType<EllipseBFFP> );
+    Object::addBuiltinType( new TStdType<HyperbolaBFFP> );
+//     Object::addBuiltinType( new TStdType<ConicBDF> );
+    Object::addBuiltinType( new TStdType<ConicB5P> );
+    Object::addBuiltinType( new TStdType<ParabolaBTP> );
+    Object::addBuiltinType( new TStdType<EquilateralHyperbolaB4P> );
     Object::addBuiltinType( new TStdType<MidPoint> );
     Object::addBuiltinType( new TStdType<IntersectionPoint> );
     Object::addBuiltinType( new TMultiType<CircleLineIntersectionPoint> );
+    Object::addBuiltinType( new TMultiType<ConicLineIntersectionPoint> );
     Object::addBuiltinType( new TStdType<TranslatedPoint> );
     Object::addBuiltinType( new TStdType<MirrorPoint> );
     Object::addBuiltinType( new TStdType<Locus> );
     Object::addBuiltinType( new TStdType<Vector> );
     Object::addBuiltinType( new TStdType<Ray> );
     Object::addBuiltinType( new TStdType<Arc> );
+    Object::addBuiltinType( new TStdType<LineDirectrix> );
+    Object::addBuiltinType( new TStdType<LinePolar> );
+    Object::addBuiltinType( new TStdType<PointPolar> );
     Object::addBuiltinType( new TType<TextLabel> );
     Object::addBuiltinType( new TType<NormalPoint> );
+    Object::addBuiltinType( new TUnconstructibleType<CoordinatePropertyPoint> );
 
     // our saved macro types:
     QStringList relFiles;
@@ -301,15 +321,13 @@ bool KigDocument::openFile()
   mhistory->clear();
 
   Objects tmp = calcPath( os );
-  // terrible hackery, i know..
-  tmp.calc( ScreenInfo( Rect(), QRect() ) );
+  tmp.calc();
   emit recenterScreen();
-  // we do it again to avoid problems with points on locuses and such...
-  tmp.calc( m_widget->screenInfo() );
+  // we do it again to avoid problems with points on locuses and such,
+  // for which the size of the current screen matters..
+  tmp.calcForWidget( *m_widget->realWidget() );
   emit recenterScreen();
-  // i think ( hope ;) three times should be enough to avoid all
-  // possible problems...
-  tmp.calc( m_widget->screenInfo() );
+  tmp.calcForWidget( *m_widget->realWidget() );
 
   return true;
 }
@@ -406,13 +424,13 @@ void KigDocument::_delObject(Object* o)
   setModified(true);
 };
 
-Objects KigDocument::whatAmIOn(const Coordinate& p, const double miss ) const
+Objects KigDocument::whatAmIOn(const Coordinate& p, const ScreenInfo& si ) const
 {
   Objects tmp;
   Objects nonpoints;
   for ( Objects::const_iterator i = mObjs.begin(); i != mObjs.end(); ++i )
   {
-    if(!(*i)->contains(p, miss) || !(*i)->shown() || !(*i)->valid()) continue;
+    if(!(*i)->contains(p, si) || !(*i)->shown() || !(*i)->valid()) continue;
     if ( (*i)->toPoint()) tmp.push_back(*i);
     else nonpoints.push_back( *i );
   };
@@ -436,7 +454,7 @@ Objects KigDocument::whatIsInHere( const Rect& p )
 
 Rect KigDocument::suggestedRect()
 {
-  if( mObjs.empty() ) return Rect( -2, -2, 2, 2 );
+  if( mObjs.empty() ) return Rect( -7, -7, 7, 7 );
   bool rectInited = false;
   Rect r(0,0,0,0);
   Point* p;
@@ -463,9 +481,10 @@ Rect KigDocument::suggestedRect()
   return r;
 }
 
-const CoordinateSystem* KigDocument::coordinateSystem()
+const CoordinateSystem& KigDocument::coordinateSystem() const
 {
-  return s;
+  assert( s );
+  return *s;
 }
 
 void KigDocument::setMode( KigMode* m )
@@ -542,6 +561,8 @@ void KigDocument::addType( Type* t, bool user )
       aMNewLine.append( a );
     else if (t->baseTypeName() == Circle::sBaseTypeName())
       aMNewCircle.append( a );
+    else if (t->baseTypeName() == Conic::sBaseTypeName())
+      aMNewConic.append( a );
     else if (t->baseTypeName() == Segment::sBaseTypeName())
       aMNewSegment.append( a );
     else
@@ -567,6 +588,7 @@ void KigDocument::enableConstructActions( bool enabled )
                                enabled ) );
   aFixedPoint->setEnabled( enabled );
 
+  setEnabled( aMNewConic, enabled );
   setEnabled( aMNewSegment, enabled );
   setEnabled( aMNewPoint, enabled );
   setEnabled( aMNewCircle, enabled );
@@ -584,6 +606,7 @@ myvector<KigDocument*>& KigDocument::documents()
 void KigDocument::removeAction( KAction* a )
 {
   aMNewSegment.remove( a );
+  aMNewConic.remove( a );
   aMNewPoint.remove( a );
   aMNewCircle.remove( a );
   aMNewLine.remove( a );
@@ -594,6 +617,7 @@ void KigDocument::removeAction( KAction* a )
 
 void KigDocument::unplugActionLists()
 {
+  unplugActionList( "user_conic_types" );
   unplugActionList( "user_segment_types" );
   unplugActionList( "user_point_types" );
   unplugActionList( "user_circle_types" );
@@ -604,6 +628,7 @@ void KigDocument::unplugActionLists()
 
 void KigDocument::plugActionLists()
 {
+  plugActionList( "user_conic_types", aMNewConic );
   plugActionList( "user_segment_types", aMNewSegment );
   plugActionList( "user_point_types", aMNewPoint );
   plugActionList( "user_circle_types", aMNewCircle );
@@ -651,3 +676,8 @@ bool KigDocument::internalSaveAs()
   saveAs(file_name);
   return true;
 }
+
+KigView* KigDocument::mainWidget()
+{
+  return m_widget;
+}
