@@ -42,6 +42,7 @@ class CoordinateSystem;
 class MacroWizardImpl;
 class KigView;
 class Object;
+class ScreenInfo;
 
 /**
  * This is a "Part".  It that does all the real work in a KPart
@@ -74,6 +75,8 @@ public:
 
   static myvector<KigDocument*>& documents();
 
+  KigView* mainWidget();
+
 /*********************** KPart interface *************************/
 
 public:
@@ -97,7 +100,6 @@ signals:
 public:
   void emitStatusBarText( const QString& text );
 
-  /***************** some slots *************************/
 public slots:
   void fileSaveAs();
   void fileSave();
@@ -122,12 +124,12 @@ public:
   void delView(KigView*) { numViews--; };
 
   const Objects& objects() { return mObjs;};
-  const CoordinateSystem* coordinateSystem();
+  const CoordinateSystem& coordinateSystem() const;
   KigMode* mode() { return mMode; };
   void setMode( KigMode* );
 
   // what objects are under point p
-  Objects whatAmIOn( const Coordinate& p, const double fault ) const;
+  Objects whatAmIOn( const Coordinate& p, const ScreenInfo& si ) const;
 
   Objects whatIsInHere( const Rect& p );
 
@@ -183,6 +185,7 @@ public:
   QPtrList<KAction> aMNewLine;
   QPtrList<KAction> aMNewOther;
   QPtrList<KAction> aMNewAll;
+  QPtrList<KAction> aMNewConic;
 
   KAction* aCancelConstruction;
   KAction* aDeleteObjects;
