@@ -22,12 +22,14 @@
 
 #include "../kig/kig_view.h"
 #include "../objects/object.h"
+#include "../objects/conic.h"
 #include "common.h"
 #include "coordinate_system.h"
 
 #include <qpen.h>
 
 #include <cmath>
+#include <stack>
 
 KigPainter::KigPainter( const ScreenInfo& si, QPaintDevice* device, bool no )
   : mP ( device ),
@@ -72,28 +74,28 @@ void KigPainter::drawSegment( const Coordinate& from, const Coordinate& to )
   if( mNeedOverlay ) segmentOverlay( from, to );
 }
 
-void KigPainter::drawPoint( const Coordinate& p, bool s )
+void KigPainter::drawFatPoint( const Coordinate& p, double radius )
 {
-  if( s )
-  {
-    mP.drawPoint( toScreen(p) );
-    if( mNeedOverlay ) pointOverlay( p );
-  }
-  else
-  {
-    setBrushStyle( Qt::SolidPattern );
-    QRect r( 0, 0, 5, 5 );
-    r.moveCenter( toScreen( p ) );
-    mP.drawEllipse( r );
-    if( mNeedOverlay ) mOverlay.push_back( r );
-  }
+  setBrushStyle( Qt::SolidPattern );
+  Coordinate rad( radius, radius );
+  rad /= 2;
+  Coordinate tl = p - rad;
+  Coordinate br = p + rad;
+  Rect r( tl, br );
+  QRect qr = toScreen( r );
+  mP.drawEllipse( qr );
+  if( mNeedOverlay ) mOverlay.push_back( qr );
+}
+
+void KigPainter::drawPoint( const Coordinate& p )
+{
+  mP.drawPoint( toScreen(p) );
+  if( mNeedOverlay ) pointOverlay( p );
 }
 
 void KigPainter::drawLine( const Coordinate& p1, const Coordinate& p2 )
 {
-  Coordinate ba = p1, bb = p2;
-  calcBorderPoints( ba, bb, window() );
-  drawSegment( ba, bb );
+  drawLine( LineData( p1, p2 ) );
 }
 
 void KigPainter::drawText( const Rect p, const QString s, int textFlags, int len )
@@ -257,10 +259,14 @@ void KigPainter::segmentOverlay( const Coordinate& p1, const Coordinate& p2 )
 
   // some stuff we may need:
   Coordinate p3 = p2 - p1;
-  double length = p3.length();
   Rect border = window();
-  // if length is smaller than one, we risk getting a divide by zero
-  length = std::max( length, 1. );
+  double length = p3.length();
+  if ( length < 10e-20 )
+  {
+    // hopefully prevent SIGZERO's
+    mOverlay.push_back( toScreen( Rect( p1, p2 ) ) );
+    return;
+  };
   p3 *= overlayRectSize();
   p3 /= length;
 
@@ -270,7 +276,6 @@ void KigPainter::segmentOverlay( const Coordinate& p1, const Coordinate& p2 )
   r.normalize();
 
   for (;;) {
-    // sanity check...
     Rect tR( Coordinate( 0, 0 ), overlayRectSize(), overlayRectSize() );
     Coordinate tP = p1+p3*counter;
     tR.setCenter(tP);
@@ -318,9 +323,9 @@ QPoint KigPainter::toScreen( const Coordinate p ) const
   return msi.toScreen( p );
 }
 
-void KigPainter::drawGrid( const CoordinateSystem* c )
+void KigPainter::drawGrid( const CoordinateSystem& c )
 {
-  c->drawGrid( *this );
+  c.drawGrid( *this );
   setWholeWinOverlay();
 }
 
@@ -367,8 +372,6 @@ QRect KigPainter::toScreen( const Rect r ) const
 void KigPainter::drawSimpleText( const Coordinate& c, const QString s )
 {
   int tf = AlignLeft | AlignTop | DontClip | WordBreak;
-  setPen(QPen(Qt::blue, 1, SolidLine));
-  setBrush(Qt::NoBrush);
   drawText( c, s, tf);
 }
 
@@ -417,3 +420,141 @@ void KigPainter::drawArc( const Rect& surroundingRect, int startAngle, int angle
 //  if ( mNeedOverlay ) mOverlay.push_back( toScreen( r ) );
   setWholeWinOverlay();
 }
+
+void KigPainter::drawFatPoint( const Coordinate& p )
+{
+    drawFatPoint( p, 5 * pixelWidth() );
+}
+
+inline Coordinate conicGetCoord( double theta, double ecostheta0,
+                                 double esintheta0, double pdimen,
+                                 const Coordinate& focus1 )
+{
+  // TODO: eliminate some cos() and sin() calls with a table...
+  double costheta = cos( theta );
+  double sintheta = sin( theta );
+  double ecosthetamtheta = costheta*ecostheta0 + sintheta*esintheta0;
+  double rho = pdimen / (1.0 - ecosthetamtheta);
+  return focus1 + rho * Coordinate( costheta, sintheta );
+};
+
+void KigPainter::drawConic( const ConicPolarEquationData& data )
+{
+  // @author Maurizio Paolini wrote an original version of this, ( the
+  // math in conicGetCoord() is still his ), I ( Dominique ) adapted
+  // it afterwards to use a distribution mechanism as explained
+  // below. )
+
+  // this function works more or less like Locus::calcForWidget():
+  // we calc some initial points, draw them, and then keep checking if
+  // the point with the param in between two other points.  If the
+  // point with that param is not too close to one of them, and if it
+  // is in the current window(), then we draw it, and put it on the
+  // stack for further processing...
+
+  Coordinate focus1 = data.focus1;
+  double pdimen = data.pdimen;
+  double ecostheta0 = data.ecostheta0;
+  double esintheta0 = data.esintheta0;
+
+  // we manage our own overlay
+  bool tNeedOverlay = mNeedOverlay;
+  mNeedOverlay = false;
+  Rect overlay;
+
+  // this stack contains pairs of Coordinates that we still need to
+  // process:
+  typedef std::pair<double,Coordinate> coordparampair;
+  typedef std::pair<coordparampair, coordparampair> workitem;
+  std::stack<workitem> workstack;
+
+  // first work on some 20 initial points and push them onto the
+  // stack.. :
+  coordparampair prev =
+    coordparampair( 0, conicGetCoord( 0, ecostheta0, esintheta0,
+                                      pdimen, focus1 ) );
+
+  for ( double i = M_PI/20; i <= 2*M_PI; i += M_PI/20 )
+  {
+    Coordinate c = conicGetCoord( i, ecostheta0, esintheta0,
+                                  pdimen, focus1 );
+    workstack.push( workitem( coordparampair( i, c ), prev ) );
+    prev = coordparampair( i, c );
+  };
+
+  // maxlength is the square of the maximum size that we allow
+  // between two points..
+  double maxlength = 1.5 * pixelWidth();
+  maxlength *= maxlength;
+  // error squared is required to be less that sigma (half pixel)
+  double sigma = maxlength/4;
+  // distance between two parameter values cannot be too small
+  double hmin = 1e-4;
+
+  int count = 20;              // the number of points we've already
+                               // visited...
+  static const int maxnumberofpoints = 1000;
+
+  const Rect& sr = window();
+
+  // we don't use recursion, but a stack based approach for efficiency
+  // concerns...
+  while ( ! workstack.empty() && count < maxnumberofpoints )
+  {
+    workitem curitem = workstack.top();
+    workstack.pop();
+    bool curitemok = true;
+    while ( curitemok && count++ < maxnumberofpoints )
+    {
+      // we take the middle parameter of the two previous points...
+      Coordinate p0 = curitem.first.second;
+      Coordinate p1 = curitem.second.second;
+      double t2 = ( curitem.first.first + curitem.second.first ) / 2;
+      double h = fabs( curitem.second.first - curitem.first.first ) /2;
+      Coordinate p2 = conicGetCoord( t2, ecostheta0, esintheta0,
+                                    pdimen, focus1 );
+      bool addn = sr.contains( p2 );
+      // estimated error between the curve and the segments
+      double errsq = (0.5*p0 + 0.5*p1 - p2).squareLength();
+      errsq /= 4;
+      curitemok = false;
+      if ( errsq < sigma || h < hmin )
+      {
+        // draw the two segments
+        overlay.setContains( p0 );
+        overlay.setContains( p1 );
+        overlay.setContains( p2 );
+        QPoint tp0 = toScreen(p0);
+        QPoint tp1 = toScreen(p1);
+        QPoint tp2 = toScreen(p2);
+        mP.drawLine( tp0, tp2 );
+        mP.drawLine( tp2, tp1 );
+      }
+      else
+      {
+        // push into stack in order to process both subintervals
+        if (addn || sr.contains( p0 ) )
+          workstack.push( workitem( curitem.first, coordparampair( t2, p2 ) ) );
+        if (addn || sr.contains( p1 ) )
+        {
+          curitem = workitem( coordparampair( t2, p2 ), curitem.second );
+          curitemok = true;
+        }
+      }
+    }
+  }
+
+  mOverlay.push_back( toScreen( overlay ) );
+  mNeedOverlay = tNeedOverlay;
+}
+
+void KigPainter::drawLine( const LineData& d )
+{
+  LineData l = calcBorderPoints( d, window() );
+  drawSegment( l );
+}
+
+void KigPainter::drawSegment( const LineData& d )
+{
+  drawSegment( d.a, d.b );
+}
