@@ -36,6 +36,8 @@ class KigWidget;
 class QPaintDevice;
 class CoordinateSystem;
 class Object;
+class ConicPolarEquationData;
+struct LineData;
 
 /**
  * KigPainter is an extended qpainter...
@@ -136,6 +138,7 @@ public:
    * draw a segment...
    */
   void drawSegment ( const Coordinate& from, const Coordinate& to );
+  void drawSegment( const LineData& d );
 
   /**
    * draw a ray...
@@ -146,13 +149,21 @@ public:
    * draw a line...
    */
   void drawLine ( const Coordinate& p1, const Coordinate& p2 );
+  void drawLine( const LineData& d );
 
   /**
-   * draw a point...
-   * small == true means only draw a single dot, otherwise an ellipse
-   * will be drawn as for Point objects
+   * draw a point...  This means a single point, as in
+   * QPainter::drawPoint(), unlike drawFatPoint()...
    */
-  void drawPoint( const Coordinate& p, bool small = true );
+  void drawPoint( const Coordinate& p );
+
+  /**
+   * draw a thick point..  This is what the user sees when he draws a
+   * point.  In fact it isn't a point, but a filled circle of a
+   * certain @param radius...
+   */
+  void drawFatPoint( const Coordinate& p, double radius );
+  void drawFatPoint( const Coordinate& p );   // default args don't seem to work properly..
 
   /**
    * draw a polygon defined by the points in pts...
@@ -168,6 +179,11 @@ public:
    */
   void drawArc( const Rect& surroundingRect, int startAngle, int angle );
 
+  /**
+   * draw a conic..
+   */
+  void drawConic( const ConicPolarEquationData& data );
+
   /*
    * draw text...
    * @see QPainter::drawText()
@@ -187,7 +203,7 @@ public:
 
   const Rect simpleBoundingRect( const Coordinate& c, const QString s );
 
-  void drawGrid( const CoordinateSystem* c );
+  void drawGrid( const CoordinateSystem& c );
 
   const std::vector<QRect>& overlay() { return mOverlay; };
 
