@@ -1,5 +1,5 @@
 // kiosk.h
-// Copyright (C)  2002  Dominique Devriese <fritmebufstek@pandora.be>
+// Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -28,13 +28,13 @@ class KioskMode
 public:
   KioskMode( KigDocument* );
   ~KioskMode();
-  void leftClicked( QMouseEvent*, KigView* );
-  void midClicked( QMouseEvent*, KigView* );
-  void rightClicked( QMouseEvent*, KigView* );
-  void leftReleased( QMouseEvent*, KigView* );
-  void midReleased( QMouseEvent*, KigView* );
-  void rightReleased( QMouseEvent*, KigView* );
-  void mouseMoved( QMouseEvent*, KigView* );
+  void leftClicked( QMouseEvent*, KigWidget* );
+  void midClicked( QMouseEvent*, KigWidget* );
+  void rightClicked( QMouseEvent*, KigWidget* );
+  void leftReleased( QMouseEvent*, KigWidget* );
+  void midReleased( QMouseEvent*, KigWidget* );
+  void rightReleased( QMouseEvent*, KigWidget* );
+  void mouseMoved( QMouseEvent*, KigWidget* );
 };
 
 #endif
