@@ -35,7 +35,7 @@ NormalModePopupObjects::NormalModePopupObjects( KigDocument* doc,
                                                 KigWidget* view,
                                                 NormalMode* mode,
                                                 const Objects& objs )
-  : mdoc( doc ), mview( view ), mobjs( objs ), mmode( mode )
+  : mplc( QCursor::pos() ), mdoc( doc ), mview( view ), mobjs( objs ), mmode( mode )
 {
   assert ( ! objs.empty() );
   bool single = objs.size() == 1;
@@ -85,11 +85,10 @@ void NormalModePopupObjects::doAction( int i )
   {
     // i >= restOffset, which means that one of the object specific actions was
     // activated...
-    assert( (uint) i >= restOffset );
+    assert( (uint) i >= virtualActionsOffset );
     assert( mobjs.size() == 1 );
     Object* o = mobjs[0];
-    assert( ((uint)i) - restOffset < o->objectActions().size() );
-    o->doAction( i - restOffset, mdoc, mview, mmode );
+    o->doNormalAction( i, mdoc, mview, mmode, mview->fromScreen( mview->mapFromGlobal( mplc ) ) );
   }
   };
   mmode->clearSelection();
@@ -114,8 +113,7 @@ const QColor* NormalModePopupObjects::color( int i )
 
 QPopupMenu* NormalModePopupObjects::colorMenu( QWidget* parent )
 {
-  QPopupMenu* m = 0;
-  m = new QPopupMenu( parent, "color popup menu" );
+  QPopupMenu* m = new QPopupMenu( parent, "color popup menu" );
   const QColor* c = 0;
   QPixmap p( 50, 20 );
   for( uint i = 0; ( c = color( i ) ); ++i )
@@ -127,7 +125,7 @@ QPopupMenu* NormalModePopupObjects::colorMenu( QWidget* parent )
   return m;
 }
 
-void NormalModePopupObjects::setColor( int c )
+void NormalModePopupObjects::doSetColor( int c )
 {
   const QColor* d = color( c );
   assert( d );
@@ -142,7 +140,7 @@ void NormalModePopupObjects::setColor( int c )
 void NormalModePopupObjects::addColorPopup()
 {
   QPopupMenu* colorpopup = colorMenu( this );
-  connect( colorpopup, SIGNAL( activated( int ) ), this, SLOT( setColor( int ) ) );
+  connect( colorpopup, SIGNAL( activated( int ) ), this, SLOT( doSetColor( int ) ) );
   uint id = insertItem( i18n( "Set Color..." ), colorpopup, colorId );
   assert( id == colorId );
 }
@@ -195,14 +193,8 @@ void NormalModePopupObjects::addVirtualItems()
 {
   if ( mobjs.size() == 1 )
   {
-    uint id = restOffset;
     // we show the object-specific actions...
-    QStringList l = mobjs[0]->objectActions();
-    for ( QStringList::const_iterator i = l.begin(); i != l.end(); ++i, ++id )
-    {
-      uint rid = insertItem( *i, id );
-      assert( rid == id );
-    };
+    mobjs[0]->addActions( *this );
   };
 }
 
@@ -228,7 +220,7 @@ void NormalModePopupObjects::doUse( int id )
   {
     Object* o = type->build( mobjs );
     assert( o );
-    o->calc( mview->screenInfo() );
+    o->calcForWidget( *mview );
     mdoc->addObject( o );
     mmode->clearSelection();
     break;
@@ -249,3 +241,36 @@ void NormalModePopupObjects::doUse( int id )
     break;
   };
 }
+
+void NormalModePopupObjects::addPopupAction( uint id, const QString& name, QPopupMenu* pm )
+{
+  connect( pm, SIGNAL( activated( int ) ), SLOT( doPopup( int ) ) );
+  mpopupmap[pm] = id;
+  insertItem( name, pm, id );
+}
+
+void NormalModePopupObjects::addNormalAction( uint id, const QString& name )
+{
+  uint rid = insertItem( name, id );
+  assert( rid == id );
+}
+
+void NormalModePopupObjects::doPopup( int id )
+{
+  // sender() is a very ugly QObject member that returns the object
+  // that called this slot.  Did I mention i find the entire Qt Object
+  // Model ugly as hell ?  /me throws the Design Patterns book at the
+  // TrollTech coders...
+  // but we use it here anyway, since we need it...
+  const QObject* qo = sender();
+  const QPopupMenu* qp = static_cast<const QPopupMenu*>( qo );
+  int popupid = mpopupmap[qp];
+  assert( mobjs.size() == 1 );
+  Object* o = mobjs[0];
+  o->doPopupAction( popupid, id, mdoc, mview, mmode, mview->fromScreen( mview->mapFromGlobal( mplc ) ) );
+}
+
+const KigWidget& NormalModePopupObjects::widget() const
+{
+  return *mview;
+}
