@@ -16,11 +16,13 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 // 02111-1307, USA.
 
-#ifndef DIRECTION_H
-#define DIRECTION_H
+#ifndef ABSTRACTLINE_H
+#define ABSTRACTLINE_H
 
 #include "curve.h"
 
+struct LineData;
+
 /**
  * This class is an abstract interface to an object that is somewhat
  * of a line.. Examples are Line, Segment, Ray etc.
@@ -28,14 +30,24 @@
 class AbstractLine
   : public Curve
 {
+  int msize;
 public:
   AbstractLine();
   AbstractLine( const AbstractLine& l );
   virtual const Coordinate p1() const = 0;
   virtual const Coordinate p2() const = 0;
-  const Coordinate direction();
+  const LineData lineData() const;
+
+  const Coordinate direction() const;
   const AbstractLine* toAbstractLine() const { return this; };
   AbstractLine* toAbstractLine() { return this; };
+
+  double slope() const;
+
+  const uint numberOfProperties() const;
+  const Property property( uint which, const KigWidget& w ) const;
+  const QCStringList properties() const;
+  const QString equationString( const KigWidget& w ) const;
 };
 
 #endif
