@@ -24,10 +24,11 @@
 
 #include "../misc/common.h"
 #include "../misc/kigpainter.h"
+#include "../misc/i18n.h"
+#include "../misc/coordinate_system.h"
+#include "../kig/kig_view.h"
+#include "../kig/kig_part.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <qpen.h>
 #include <math.h>
 
 Circle::Circle()
@@ -38,9 +39,9 @@ Circle::~Circle()
 {
 };
 
-bool Circle::contains (const Coordinate& o, const double miss) const
+bool Circle::contains (const Coordinate& o, const ScreenInfo& si ) const
 {
-  return fabs((qpc - Coordinate(o)).length() - mradius) <= miss;
+  return fabs((qpc - Coordinate(o)).length() - mradius) <= si.normalMiss();
 };
 
 void Circle::draw (KigPainter& p, bool ss) const
@@ -81,7 +82,7 @@ CircleBCP::CircleBCP( const Objects& os )
   centre->addChild( this );
 };
 
-void CircleBCP::calc( const ScreenInfo& )
+void CircleBCP::calc()
 {
   if (poc->valid() && centre->valid())
   {
@@ -150,7 +151,7 @@ Objects CircleBCP::getParents() const
   return objs;
 }
 
-void CircleBTP::calc( const ScreenInfo& )
+void CircleBTP::calc()
 {
   mvalid = true;
   for ( Point** i = pts; i < pts + 3; ++i )
@@ -231,7 +232,7 @@ const char* CircleBTP::sActionName()
 }
 
 Circle::Circle( const Circle& c )
-  : Curve( c ), qpc( c.qpc ), mradius( c.mradius )
+  : Conic( c ), qpc( c.qpc ), mradius( c.mradius )
 {
 }
 
@@ -363,17 +364,102 @@ const Circle* Circle::toCircle() const
   return this;
 }
 
-void CircleBCP::startMove(const Coordinate&)
+const ConicCartesianEquationData Circle::cartesianEquationData() const
 {
-  // moving is disabled..
+  Coordinate c = center();
+  double sqr = squareRadius();
+  ConicCartesianEquationData data(1.0, 1.0, 0.0, -2*c.x, -2*c.y,
+    c.x*c.x + c.y*c.y - sqr);
+  return data;
 }
 
-void CircleBCP::moveTo(const Coordinate&)
+const ConicPolarEquationData Circle::polarEquationData() const
 {
-  // moving is disabled..
+  return ConicPolarEquationData( center(), radius(), 0, 0 );
 }
 
-void CircleBCP::stopMove()
+QString Circle::cartesianEquationString( const KigWidget& ) const
 {
-  // moving is disabled..
-};
+  QString ret = i18n( "x^2 + y^2 + %1 x + %2 y + %3 = 0" );
+  ConicCartesianEquationData data = cartesianEquationData();
+  ret = ret.arg( data.coeffs[3], 0, 'g', 3 );
+  ret = ret.arg( data.coeffs[4], 0, 'g', 3 );
+  ret = ret.arg( data.coeffs[5], 0, 'g', 3 );
+  return ret;
+}
+
+QString Circle::polarEquationString( const KigWidget& w ) const
+{
+  QString ret = i18n( "rho = %1   [centered at %2]" );
+  ConicPolarEquationData data = polarEquationData();
+  ret = ret.arg( data.pdimen, 0, 'g', 3 );
+  ret = ret.arg( w.document().coordinateSystem().fromScreen( data.focus1, w ) );
+  return ret;
+}
+
+const uint Circle::numberOfProperties() const
+{
+  return Curve::numberOfProperties() + 6;
+}
+
+const Property Circle::property( uint which, const KigWidget& w ) const
+{
+  assert( which < Circle::numberOfProperties() );
+  if ( which < Curve::numberOfProperties() ) return Curve::property( which, w );
+  if ( which == Curve::numberOfProperties() )
+    return Property( surface() );
+  else if ( which == Curve::numberOfProperties() + 1 )
+    return Property( circumference() );
+  else if ( which == Curve::numberOfProperties() + 2 )
+    return Property( radius() );
+  else if ( which == Curve::numberOfProperties() + 3 )
+    return Property( center() );
+  else if ( which == Curve::numberOfProperties() + 4 )
+    return Property( cartesianEquationString( w ) );
+  else if ( which == Curve::numberOfProperties() + 5 )
+    return Property( polarEquationString( w ) );
+  else assert( false );
+}
+
+const QCStringList Circle::properties() const
+{
+  QCStringList l = Curve::properties();
+  l << I18N_NOOP( "Surface" );
+  l << I18N_NOOP( "Circumference" );
+  l << I18N_NOOP( "Radius" );
+  l << I18N_NOOP( "Center" );
+  l << I18N_NOOP( "Cartesian equation" );
+  l << I18N_NOOP( "Polar equation" );
+  assert( l.size() == Circle::numberOfProperties() );
+  return l;
+}
+
+double Circle::surface() const
+{
+  return M_PI * squareRadius();
+}
+
+double Circle::circumference() const
+{
+  return 2 * M_PI * radius();
+}
+
+Coordinate Circle::center() const
+{
+  return qpc;
+}
+
+int Circle::conicType() const
+{
+  return 1;
+}
+
+Coordinate Circle::focus1() const
+{
+  return center();
+}
+
+Coordinate Circle::focus2() const
+{
+  return focus1();
+}
