@@ -23,16 +23,21 @@
 #define CIRCLE_H
 
 #include "curve.h"
+#include "conic.h"
 #include "../misc/common.h"
 
 class Circle
-: public Curve
+  : public Conic
 {
  public:
   Circle();
   Circle( const Circle& c );
   ~Circle();
 
+  const uint numberOfProperties() const;
+  const Property property( uint which, const KigWidget& w ) const;
+  const QCStringList properties() const;
+
   Circle* toCircle();
   const Circle* toCircle() const;
 
@@ -40,15 +45,25 @@ class Circle
   virtual const QCString vBaseTypeName() const { return sBaseTypeName();};
   static const QCString sBaseTypeName();
 
-  bool contains (const Coordinate& o, const double miss ) const;
+  bool contains (const Coordinate& o, const ScreenInfo& si ) const;
   void draw (KigPainter& p, bool showSelection) const;
   bool inRect (const Rect&) const;
   Coordinate getPoint (double param) const;
   double getParam (const Coordinate&) const;
 
-  Coordinate getCenter() const { return qpc; };
+  Coordinate center() const;
   double radius() const;
   double squareRadius() const;
+  double surface() const;
+  double circumference() const;
+  QString cartesianEquationString( const KigWidget& w ) const;
+  QString polarEquationString( const KigWidget& ) const;
+  const ConicCartesianEquationData cartesianEquationData() const;
+  const ConicPolarEquationData polarEquationData() const;
+  virtual int conicType() const;
+  virtual Coordinate focus1() const;
+  virtual Coordinate focus2() const;
+
 
 protected:
   Coordinate qpc;
@@ -80,7 +95,7 @@ public:
   static const int sShortCut() { return CTRL+Key_C; };
   static const char* sActionName();
 
-  void calc( const ScreenInfo& showingRect );
+  void calc();
 
   // passing arguments
   static Object::WantArgsResult sWantArgs( const Objects& os );
@@ -89,15 +104,9 @@ public:
 
   Objects getParents() const;
 
-  //moving is disabled..
-  void startMove(const Coordinate&);
-  void moveTo(const Coordinate&);
-  void stopMove();
 protected:
   Point* poc; // point on circle
   Point* centre;
-  Coordinate pwpsm; // point where poc started moving
-  enum { notMoving, movingPoc, lettingPocMove } wawm; // what are we moving ?
 };
 
 class CircleBTP
@@ -116,7 +125,7 @@ public:
   const QString vDescription() const { return sDescription(); };
   static const QString sDescription();
   const QCString vIconFileName() const { return sIconFileName(); };
-  static const QCString sIconFileName() { return "circle"; };
+  static const QCString sIconFileName() { return "circlebtp"; };
   const int vShortCut() const { return sShortCut(); };
   static const int sShortCut() { return 0; };
   static const char* sActionName();
@@ -128,16 +137,10 @@ public:
 
   Objects getParents() const;
 
-  //moving
-  void startMove(const Coordinate&) {};
-  void moveTo(const Coordinate&) {};
-  void stopMove() {};
-  void cancelMove() {};
-
 protected:
   Point* pts[3];
 
-  void calc( const ScreenInfo& showingRect );
+  void calc();
   static Coordinate calcCenter( Coordinate, Coordinate, Coordinate );
 };
 
