@@ -25,7 +25,6 @@
 #include "circle.h"
 
 #include "../modes/constructing.h"
-#include "../misc/kigpainter.h"
 #include "../misc/common.h"
 #include "../misc/i18n.h"
 
@@ -39,17 +38,12 @@ Objects IntersectionPoint::getParents() const
   return tmp;
 };
 
-void IntersectionPoint::calc( const ScreenInfo& )
+void IntersectionPoint::calc()
 {
   mvalid = true;
-  Coordinate t1, t2, t3, t4;
   mvalid &= mla->valid();
-  t1 = mla->p1();
-  t2 = mla->p2();
   mvalid &= mlb->valid();
-  t3 = mlb->p1();
-  t4 = mlb->p2();
-  if ( mvalid ) mC = calcIntersectionPoint( t1, t2, t3, t4 );
+  if ( mvalid ) mC = calcIntersectionPoint( mla->lineData(), mlb->lineData() );
 }
 
 const QString IntersectionPoint::sDescriptiveName()
@@ -119,18 +113,6 @@ const int IntersectionPoint::sShortCut()
   return CTRL+Key_I;
 }
 
-void IntersectionPoint::startMove(const Coordinate& )
-{
-}
-
-void IntersectionPoint::moveTo(const Coordinate& )
-{
-}
-
-void IntersectionPoint::stopMove()
-{
-}
-
 const char* IntersectionPoint::sActionName()
 {
   return "objects_new_intersectionpoint";
@@ -154,27 +136,22 @@ IntersectionPoint::IntersectionPoint( const Objects& os )
 void IntersectionPoint::sDrawPrelim( KigPainter& p, const Objects& os )
 {
   if ( os.size() != 2 ) return;
-  Coordinate pa, pb, pc, pd;
+  LineData la, lb;
   bool gota = false;
-  AbstractLine* l;
+  AbstractLine* l = 0;
   for ( Objects::const_iterator i = os.begin(); i != os.end(); ++i )
   {
     l = (*i)->toAbstractLine();
     assert( l );
     if ( gota )
-    {
-      pc = l->p1();
-      pd = l->p2();
-    }
+      lb = l->lineData();
     else
     {
       gota = true;
-      pa = l->p1();
-      pb = l->p2();
+      la = l->lineData();
     };
   };
-  p.setPen( QPen( Qt::red, 1 ) );
-  p.drawPoint( calcIntersectionPoint( pa, pb, pc, pd ), false );
+  sDrawPrelimPoint( p, calcIntersectionPoint( la, lb ) );
 }
 
 Object::WantArgsResult IntersectionPoint::sWantArgs( const Objects& os )
@@ -256,7 +233,7 @@ const QCString CircleLineIntersectionPoint::vIconFileName() const
 
 const QCString CircleLineIntersectionPoint::sIconFileName()
 {
-  return 0;
+  return "circlelineintersection";
 }
 
 const int CircleLineIntersectionPoint::vShortCut() const
@@ -286,19 +263,18 @@ void CircleLineIntersectionPoint::sDrawPrelim( KigPainter& p, const Objects& os
     if ( ! l ) l = (*i)->toAbstractLine();
   };
   assert( c && l );
-  const Coordinate center = c->getCenter();
+  const Coordinate center = c->center();
   const double sqr = c->squareRadius();
-  const Coordinate a = l->p1();
-  const Coordinate b = l->p2();
+  const LineData ld = l->lineData();
   bool valid = true;
-  const Coordinate d = calcCircleLineIntersect( center, sqr, a, b,
+  const Coordinate d = calcCircleLineIntersect( center, sqr, ld,
                                                 true, valid );
-  const Coordinate e = calcCircleLineIntersect( center, sqr, a, b,
+  const Coordinate e = calcCircleLineIntersect( center, sqr, ld,
                                                 false, valid );
   if ( valid )
   {
-    p.drawPoint( d, false );
-    p.drawPoint( e, false );
+    sDrawPrelimPoint( p, d );
+    sDrawPrelimPoint( p, e );
   };
 }
 
@@ -335,39 +311,27 @@ Objects CircleLineIntersectionPoint::getParents() const
   return o;
 }
 
-void CircleLineIntersectionPoint::startMove(const Coordinate& )
-{
-}
-
-void CircleLineIntersectionPoint::moveTo(const Coordinate& )
-{
-}
-
-void CircleLineIntersectionPoint::stopMove()
-{
-}
-
-void CircleLineIntersectionPoint::calc( const ScreenInfo& )
+void CircleLineIntersectionPoint::calc()
 {
   assert( mcircle && mline );
   Coordinate t;
-  t = calcCircleLineIntersect( mcircle->getCenter(), mcircle->squareRadius(),
-                               mline->p1(), mline->p2(), mside, mvalid );
+  t = calcCircleLineIntersect( mcircle->center(), mcircle->squareRadius(),
+                               mline->lineData(), mside, mvalid );
   if ( mvalid ) mC = t;
 }
 
-std::map<QCString,QString> CircleLineIntersectionPoint::getParams()
+Object::prop_map CircleLineIntersectionPoint::getParams()
 {
-  std::map<QCString,QString> map = Point::getParams();
+  prop_map map = Point::getParams();
   map["circlelineintersect-side"] = mside ? QString::fromUtf8( "first" )
                                           : QString::fromUtf8( "second" );
   return map;
 }
 
-void CircleLineIntersectionPoint::setParams( const std::map<QCString,QString>& map )
+void CircleLineIntersectionPoint::setParams( const prop_map& map )
 {
   Point::setParams( map );
-  std::map<QCString,QString>::const_iterator p = map.find("circlelineintersect-side");
+  prop_map::const_iterator p = map.find("circlelineintersect-side");
   if( p == map.end() ) mside = true;  // fixme: i'd like to throw an
                                     // error here..
   else
