@@ -54,11 +54,7 @@ public:
   static QString sUseText( const Objects& os, const Object* o );
   Objects getParents() const;
 
-  void startMove(const Coordinate& );
-  void moveTo(const Coordinate& );
-  void stopMove();
-
-  void calc( const ScreenInfo& );
+  void calc();
 };
 
 class CircleLineIntersectionPoint
@@ -93,14 +89,10 @@ public:
   static QString sUseText( const Objects& os, const Object* o );
   Objects getParents() const;
 
-  void startMove(const Coordinate& );
-  void moveTo(const Coordinate& );
-  void stopMove();
+  void calc();
 
-  void calc( const ScreenInfo& );
-
-  virtual std::map<QCString,QString> getParams ();
-  virtual void setParams ( const std::map<QCString,QString>& );
+  virtual prop_map getParams ();
+  virtual void setParams ( const Object::prop_map& );
 
   static Objects sMultiBuild( const Objects& args );
 
