@@ -30,9 +30,9 @@
 
 #include <cmath>
 
-bool Line::contains(const Coordinate& o, const double fault ) const
+bool Line::contains(const Coordinate& o, const ScreenInfo& si ) const
 {
-  return isOnLine( o, mpa, mpb, fault );
+  return isOnLine( o, mpa, mpb, si.normalMiss() );
 }
 
 void Line::draw(KigPainter& p, bool ss) const
@@ -51,18 +51,19 @@ bool Line::inRect(const Rect& p) const
 Coordinate Line::getPoint(double p) const
 {
   // inspired upon KSeg
-  p = (p - 0.5) * 2;
 
-  Coordinate m = (mpa+mpb)/2;
-  Coordinate dir = (mpa - mpb);
   // we need to spread the points over the line, it should also come near
   // the (infinite) end of the line, but most points should be near
   // the two points we contain...
-  p *= 1.5;
-  if (p>0) p = pow(p, 8);
-  else p = -pow(p,8);
-
-  return m+dir*p;
+  if ( p <= 0. ) p = 1e-6;
+  if ( p >= 1. ) p = 1 - 1e-6;
+  p = 2*p - 1;
+  if (p > 0) p = p/(1 - p);
+    else p = p/(1 + p);
+//  p *= 1024;    // such multiplying factor could be useful in order to
+                  // have more points near infinity, at the expense of
+                  // points near mpa and mpb
+  return mpa + p*(mpb - mpa); 
 };
 
 double Line::getParam(const Coordinate& point) const
@@ -70,34 +71,29 @@ double Line::getParam(const Coordinate& point) const
   // somewhat the reverse of getPoint, although it also supports
   // points not on the line...
 
-  // first we project the point onto the line...
-  Coordinate pt = calcPointOnPerpend(mpa, mpb, point);
-  pt = calcIntersectionPoint(mpa, mpb, point, pt);
+  Coordinate pa = point - mpa;
+  Coordinate ba = mpb - mpa;
+  double balsq = ba.x*ba.x + ba.y*ba.y;
+  assert (balsq > 0);
 
-  // next we fetch the parameter
-  Coordinate m = Coordinate(mpa+mpb)/2;
-  Coordinate dir = mpa - mpb;
-  Coordinate d = pt-m;
+  double p = (pa.x*ba.x + pa.y*ba.y)/balsq;
+//  p /= 1024;
+  if (p > 0) p = p/(1+p);
+    else p = p/(1-p);
 
-  double p = dir.x != 0 ? d.x/dir.x : d.y / dir.y;
-  assert( dir.x != 0 || dir.y != 0 );
-  if (p>=0) p = sqrt(sqrt(sqrt(p)));
-  else p = -sqrt(sqrt(sqrt(-p)));
-  p/=1.5;
-  p = p/2 + 0.5;
-  return p;
+  return 0.5*(p + 1);
 }
 
 LineTTP::~LineTTP()
 {
 }
 
-void LineTTP::startMove(const Coordinate& p)
+void LineTTP::startMove(const Coordinate& p, const ScreenInfo& si)
 {
   pwwsm = p;
   assert ( pt1 && pt2 );
-  pt1->startMove( p );
-  pt2->startMove( p );
+  pt1->startMove( p, si );
+  pt2->startMove( p, si );
 }
 
 void LineTTP::moveTo(const Coordinate& p)
@@ -110,7 +106,7 @@ void LineTTP::stopMove()
 {
 }
 
-void LineTTP::calc( const ScreenInfo& )
+void LineTTP::calc()
 {
   if( !pt1->valid() || !pt2->valid() )
   {
@@ -128,19 +124,7 @@ LinePerpend::~LinePerpend()
 {
 }
 
-void LinePerpend::startMove(const Coordinate&)
-{
-}
-
-void LinePerpend::moveTo(const Coordinate&)
-{
-
-}
-void LinePerpend::stopMove()
-{
-}
-
-void LinePerpend::calc( const ScreenInfo& )
+void LinePerpend::calc()
 {
   assert (point && mdir );
   mvalid = true;
@@ -179,7 +163,7 @@ Objects LineParallel::getParents() const
   return objs;
 }
 
-void LineParallel::calc( const ScreenInfo& )
+void LineParallel::calc()
 {
   assert (point && mdir );
   mvalid = true;
@@ -470,24 +454,10 @@ LineRadical::LineRadical( const Objects& os )
   c2->addChild( this );
 }
 
-Coordinate calcRadicalStartPoint( const Coordinate& ca, const Coordinate& cb,
-                                  double sqra, double sqrb )
+void LineRadical::calc()
 {
-  Coordinate direc = cb - ca;
-  Coordinate m = (ca + cb)/2;
-
-  double dsq = direc.squareLength();
-  double lambda = dsq == 0.0 ? 0.0
-                  : (sqra - sqrb) / (2*dsq);
-
-  direc *= lambda;
-  return m + direc;
-};
-
-void LineRadical::calc( const ScreenInfo& )
-{
-  Coordinate ce1 = c1->getCenter();
-  Coordinate ce2 = c2->getCenter();
+  Coordinate ce1 = c1->center();
+  Coordinate ce2 = c2->center();
   // the radical line is not defined if the centers are the same...
   if( ce1 == ce2 || !c1->valid() || !c2->valid() )
   {
@@ -496,9 +466,8 @@ void LineRadical::calc( const ScreenInfo& )
   else
   {
     mvalid = true; // else always defined...
-
-    mpa = calcRadicalStartPoint( ce1, ce2, c1->squareRadius(), c2->squareRadius() );
-    mpb = calcPointOnPerpend( ce1, ce2, mpa );
+    mpa = calcCircleRadicalStartPoint( ce1, ce2, c1->squareRadius(), c2->squareRadius() );
+    mpb = calcPointOnPerpend( LineData( ce1, ce2 ), mpa );
   };
 }
 
@@ -508,11 +477,11 @@ void LineRadical::sDrawPrelim( KigPainter& p, const Objects& os )
   Circle* ca = os[0]->toCircle();
   Circle* cb = os[1]->toCircle();
   assert ( ca && cb );
-  Coordinate pa = ca->getCenter();
-  Coordinate pb = cb->getCenter();
-  Coordinate s = calcRadicalStartPoint( pa, pb, ca->squareRadius(), cb->squareRadius() );
+  Coordinate pa = ca->center();
+  Coordinate pb = cb->center();
+  Coordinate s = calcCircleRadicalStartPoint( pa, pb, ca->squareRadius(), cb->squareRadius() );
   p.setPen( QPen (Qt::red,1) );
-  p.drawLine( s, calcPointOnPerpend( pa, pb, s ) );
+  p.drawLine( s, calcPointOnPerpend( LineData( pa, pb ), s ) );
 }
 
 Object::WantArgsResult LineRadical::sWantArgs( const Objects& os )
