@@ -39,15 +39,10 @@ public:
   virtual Line* toLine();
   virtual const Line* toLine() const;
 
-  bool contains (const Coordinate& o, const double fault ) const;
+  bool contains (const Coordinate& o, const ScreenInfo& si ) const;
   void draw (KigPainter& p, bool showSelection) const;
   bool inRect (const Rect&) const;
 
-  // moving
-  void startMove(const Coordinate&) = 0;
-  void moveTo(const Coordinate&) = 0;
-  void stopMove() = 0;
-
   // implement the Curve interface...
   Coordinate getPoint (double param) const;
   double getParam (const Coordinate&) const;
@@ -89,11 +84,11 @@ public:
   Objects getParents() const;
 
   // moving
-  void startMove(const Coordinate&);
+  void startMove(const Coordinate&, const ScreenInfo&);
   void moveTo(const Coordinate&);
   void stopMove();
 
-  void calc( const ScreenInfo& );
+  void calc();
 
 protected:
   Point* pt1;
@@ -130,12 +125,7 @@ public:
 
   Objects getParents() const;
 
-  // moving
-  void startMove(const Coordinate&);
-  void moveTo(const Coordinate&);
-  void stopMove();
-
-  void calc( const ScreenInfo& );
+  void calc();
 
 protected:
   AbstractLine* mdir;
@@ -170,12 +160,7 @@ public:
   static QString sUseText( const Objects& os, const Object* o );
   Objects getParents() const;
 
-  // moving
-  void startMove(const Coordinate&) {};
-  void moveTo(const Coordinate&) {};
-  void stopMove() {};
-
-  void calc( const ScreenInfo& );
+  void calc();
 
 protected:
   AbstractLine* mdir;
@@ -215,13 +200,7 @@ public:
   static QString sUseText( const Objects& os, const Object* o );
   Objects getParents() const;
 
-  // moving
-  // we don't move unless our parents do...
-  void startMove(const Coordinate&) {};
-  void moveTo(const Coordinate&) {};
-  void stopMove() {};
-
-  void calc( const ScreenInfo& );
+  void calc();
 
 protected:
   Circle* c1;
