@@ -23,6 +23,7 @@
 
 #include "normalpoint.h"
 
+#include "../kig/kig_view.h"
 #include "../misc/calcpaths.h"
 #include "../misc/kigpainter.h"
 #include "../misc/i18n.h"
@@ -31,27 +32,19 @@
 
 #include <kdebug.h>
 
-/**
- * Locus: the calc routines of this class are a bit unusual:
- * they're the reason we gave calc() the argument showingRect.
- * calcPointLocus only keeps points that are within the current
- * showing rect...
- */
-
 void Locus::draw(KigPainter& p, bool ss) const
 {
-  // we don't let the points draw themselves, since that would get us
-  // the big points (5x5) like we normally see them...
-  // all objs are of the same type, so we only check the first
+  // here, we simply draw the set of points we calced in the
+  // calcForWidget() function...
   p.setPen( QPen( selected && ss ? Qt::red : mColor ) );
   for (CPts::const_iterator i = pts.begin(); i != pts.end(); ++i)
     p.drawPoint( i->pt );
 }
 
-bool Locus::contains(const Coordinate& o, const double fault ) const
+bool Locus::contains(const Coordinate& o, const ScreenInfo& si ) const
 {
   for (CPts::const_iterator i = pts.begin(); i != pts.end(); ++i)
-    if( ( i->pt - o ).length() < fault ) return true;
+    if( ( i->pt - o ).length() < si.normalMiss() ) return true;
   return false;
 }
 
@@ -62,18 +55,23 @@ bool Locus::inRect(const Rect& r) const
   return false;
 }
 
-void Locus::calc( const ScreenInfo& r )
+struct PtData
 {
-  // sometimes calc() is called with an empty rect, cause the
-  // shownRect is not known yet.. we ignore those calcs...
-  if ( r.shownRect() == Rect() ) return;
+  PtData(Coordinate inc, double inp, bool inv) :
+    c(inc), p(inp), valid(inv) {};
+  Coordinate c;
+  double p;
+  bool valid;
+};
 
-  mvalid = cp->valid() && mp->valid();
+void Locus::calcForWidget( const KigWidget& w )
+{
+  mvalid = cp->valid();
   if ( mvalid )
   {
-    // i exchanged the previous recursing algorithm for a stack-based
+    // i exchanged the previous recursive algorithm for a stack-based
     // one that should be faster...  Here is the stack we use...
-    typedef std::pair<CPts::iterator, CPts::iterator> iterpair;
+    typedef std::pair<PtData, PtData> iterpair;
     std::stack<iterpair> stack;
 
     // some initial work...
@@ -83,46 +81,70 @@ void Locus::calc( const ScreenInfo& r )
     // save cp's old parameter, as we'll be changing it...
     double oldP = cp->constrainedImp()->getP();
 
-    // add 17 initial points...
-    for ( double i = 0; i <= 1; i += 1./16 )
+    // the smallest difference between parameters we allow..
+    const double hmin = 1e-4;
+
+    // fill in the prev* initially..
+    bool prevvalid = true;
+    double prevp = 1e-6;
+    Coordinate prevc = internalGetCoord( prevp, prevvalid );
+    if ( prevvalid ) pts.push_back( CPt( prevc, prevp ) );
+
+    // the number of points we already have..
+    int count = 1;
+
+    for ( double p = 1e-6 + 1./64; p < 1; p += 1./64 )
     {
-      Coordinate c = internalGetCoord( i, r );
-      pts.push_back( CPt( c, i ) );
-      if ( i != 0 ) stack.push( iterpair( pts.end() - 2, pts.end() - 1 ) );
+      bool valid = true;
+      Coordinate c = internalGetCoord( p, valid );
+      if ( valid )
+      {
+        pts.push_back( CPt( c, p ) );
+	count++;
+      }
+      if ( prevvalid || valid )
+        stack.push( iterpair( PtData( prevc, prevp, prevvalid ),
+                              PtData( c, p, valid ) ) );
+      prevc = c;
+      prevp = p;
+      prevvalid = valid;
     };
 
-    int i = 17;
-    // minlength is the square of the maximum size that we allow
+    // maxlength is the square of the maximum size that we allow
     // between two points..
-    double maxlength = 1.5 * r.pixelWidth();
+    double maxlength = 1.5 * w.pixelWidth();
     maxlength *= maxlength;
 
-    while ( ! stack.empty() && i < numberOfSamples )
+    const Rect& sr = w.screenInfo().shownRect();
+
+    while ( ! stack.empty() && count < numberOfSamples )
     {
       iterpair current = stack.top();
       stack.pop();
-      for( ; i < numberOfSamples; ++i )
+
+      for( ; count < numberOfSamples; ++count )
       {
-        double p = ( current.first->pm + current.second->pm ) / 2;
-        Coordinate n = internalGetCoord( p, r );
-        bool addn = r.shownRect().contains( n );
-        bool followfirst = addn &&
-                           ( n - current.first->pt ).squareLength() > maxlength &&
-                           r.shownRect().contains( current.first->pt );
-        bool followlast = addn &&
-                          ( n - current.second->pt ).squareLength() > maxlength &&
-                          r.shownRect().contains( current.second->pt );
+        double p = ( current.first.p + current.second.p ) / 2;
+        double h = ( current.second.p - current.first.p );
+        bool valid = true;
+        Coordinate n = internalGetCoord( p, valid );
+        bool addn = sr.contains( n ) && valid;
+        bool followfirst = ( addn || current.first.valid) && (h > hmin) &&
+                           ( n - current.first.c ).squareLength() > maxlength ;
+        bool followlast = ( addn || current.second.valid) && (h > hmin) &&
+                          ( n - current.second.c ).squareLength() > maxlength ;
         if ( addn ) pts.push_back( CPt( n, p ) );
-        if ( followfirst ) stack.push( iterpair( current.first, pts.end() - 1 ) );
-        if ( followlast ) current.first = pts.end() - 1;
+        if ( followfirst ) stack.push( iterpair( current.first,
+                PtData( n, p, addn ) ) );
+        if ( followlast ) current.first = PtData( n, p, addn );
         else break;
       };
     };
 
     // reset cp and its children to their former state...
     cp->constrainedImp()->setP(oldP);
-    cp->calc( r );
-    calcpath.calc( r );
+    cp->calcForWidget( w );
+    calcpath.calcForWidget( w );
   };
 }
 
@@ -132,21 +154,17 @@ Coordinate Locus::getPoint( double param ) const
 
   // save the old param..
   double tmp = cp->constrainedImp()->getP();
-  cp->constrainedImp()->setP(param);
-  Rect __tr;
-  ScreenInfo si ( __tr, QRect() );
-  cp->calc( si );
 
   // calc the new coord..
-  // hack... hope no-one tries recursive Locuses...
-  calcpath.calc( si );
+  cp->constrainedImp()->setP(param);
+  cp->calc();
+  calcpath.calc();
   Coordinate t = mp->getCoord();
 
   // restore the old param...
   cp->constrainedImp()->setP(tmp);
-  cp->calc( si );
-  // hack... hope no-one tries recursive Locuses...
-  calcpath.calc( si );
+  cp->calc();
+  calcpath.calc();
   return t;
 }
 
@@ -166,12 +184,14 @@ double Locus::getParam( const Coordinate& p ) const
   return optimalparam;
 }
 
-Coordinate Locus::internalGetCoord( double param, const ScreenInfo& r )
+Coordinate Locus::internalGetCoord( double param, bool& valid )
 {
   cp->constrainedImp()->setP(param);
-  cp->calc( r );
-  calcpath.calc( r );
-  return mp->getCoord();
+  cp->calc();
+  calcpath.calc();
+  valid = mp->valid();
+  if ( valid ) return mp->getCoord();
+  else return Coordinate( );
 }
 
 Locus::Locus(const Locus& loc)
@@ -264,18 +284,6 @@ const int Locus::sShortCut()
   return 0;
 }
 
-void Locus::startMove(const Coordinate&)
-{
-}
-
-void Locus::moveTo(const Coordinate&)
-{
-}
-
-void Locus::stopMove()
-{
-}
-
 const char* Locus::sActionName()
 {
   return "objects_new_locus";
@@ -331,3 +339,7 @@ QString Locus::sUseText( const Objects&, const Object* o )
 void Locus::sDrawPrelim( KigPainter&, const Objects& )
 {
 }
+
+void Locus::calc()
+{
+}
