@@ -67,7 +67,7 @@ public:
   static const char* sActionName();
 
   void draw (KigPainter& p, bool showSelection) const;
-  bool contains (const Coordinate& o, const double fault ) const;
+  bool contains (const Coordinate& o, const ScreenInfo& si ) const;
   bool inRect (const Rect&) const;
 
   // arguments
@@ -75,12 +75,8 @@ public:
   static QString sUseText( const Objects&, const Object* o );
   static void sDrawPrelim( KigPainter& p, const Objects& args );
 
-  // moving
-  void startMove(const Coordinate&);
-  void moveTo(const Coordinate&);
-  void stopMove();
-
-  void calc( const ScreenInfo& );
+  void calc();
+  void calcForWidget( const KigWidget& );
 
   Coordinate getPoint( double param ) const;
   double getParam (const Coordinate&) const;
@@ -110,6 +106,6 @@ private:
   CPts pts;
 
   // some functions used by calcPointLocus...
-  inline Coordinate internalGetCoord( double, const ScreenInfo& si );
+  inline Coordinate internalGetCoord( double, bool& valid );
 };
 #endif
