@@ -45,8 +45,6 @@ class MacroObjectOne
   // the objects we contain, these are not shown...
   Objects cos;
   Object* final;
-  // have we constructed stuff yet?
-  bool constructed;
   const MType* mtype;
 public:
   const Object* getFinal() const { return final; };
@@ -56,14 +54,16 @@ public:
   MacroObjectOne* copy() { return new MacroObjectOne(*this); };
   ~MacroObjectOne();
   void draw (KigPainter& p, bool ss) const;
-  bool contains (const Coordinate& p, const double fault ) const;
+  bool contains (const Coordinate& p, const ScreenInfo& si ) const;
   bool inRect(const Rect& r) const;
   Rect getSpan() const;
 
-  void startMove(const Coordinate& p);
+  void startMove(const Coordinate& p, const ScreenInfo&);
   void moveTo (const Coordinate& p);
   void stopMove();
-  void calc( const ScreenInfo& );
+  void calcForWidget( const KigWidget& w );
+  void calc();
+
   const QCString vBaseTypeName() const;
   const QCString vFullTypeName() const;
   const QString vDescriptiveName() const { return 0; };
@@ -75,14 +75,10 @@ public:
   const Curve* toCurve() const;
   double getParam( const Coordinate& c ) const;
   Coordinate getPoint( double param ) const;
+
+private:
+  void setValidFromParents();
+  void construct();
 };
 
-// class MacroObjectMulti
-//   : public MacroObject, public CollectionObject
-// {
-// public:
-//   MacroObjectMulti(ObjectHierarchy* inHier) : MacroObject (inHier) {};
-//   virtual void handleNewObjects (const Objects& o);
-// };
-
 #endif
