@@ -21,7 +21,7 @@
 
 #include "point.h"
 
-/** 
+/**
  * midpoint of two other points
  */
 class MidPoint
@@ -51,12 +51,11 @@ public:
   static void sDrawPrelim( KigPainter& p, const Objects& args );
   Objects getParents() const;
 
-  void startMove(const Coordinate&);
+  void startMove(const Coordinate&, const ScreenInfo&);
   void moveTo(const Coordinate&);
   void stopMove();
-  void cancelMove();
-  void calc( const ScreenInfo& r );
-  void drawPrelim( KigPainter&, const Object* ) const {};
+
+  void calc();
 protected:
   enum { howmMoving, howmFollowing } howm; // how are we moving
   Point* p1;
