@@ -21,9 +21,11 @@
 #include "curve.h"
 
 #include "../kig/kig_part.h"
+#include "../kig/kig_view.h"
 
 #include "../modes/constructing.h"
 #include "../modes/moving.h"
+#include "../modes/popup.h"
 
 QString i18n( const char* );
 
@@ -51,9 +53,9 @@ NormalPoint::~NormalPoint()
 
 void NormalPoint::redefine( const Coordinate& c,
                             const KigDocument& d,
-                            double fault )
+                            const KigWidget& w )
 {
-  Objects o = d.whatAmIOn( c, fault );
+  Objects o = d.whatAmIOn( c, w.screenInfo() );
   Curve* v = 0;
   // we don't want one of our children as a parent...
   Objects children = getAllChildren();
@@ -122,12 +124,12 @@ void NormalPoint::setCoord( const Coordinate& c )
   mC = c;
 }
 
-void FixedPointImp::calc( NormalPoint* p, const ScreenInfo& )
+void FixedPointImp::calc( NormalPoint* p )
 {
   p->setCoord( pwwca );
 }
 
-void FixedPointImp::startMove( const Coordinate& c, NormalPoint* p )
+void FixedPointImp::startMove( const Coordinate& c, NormalPoint* p, const ScreenInfo& )
 {
   pwwca = p->getCoord();
   pwwlmt = c;
@@ -143,20 +145,20 @@ void FixedPointImp::stopMove( NormalPoint* )
 {
 }
 
-std::map<QCString, QString> NormalPoint::getParams()
+Object::prop_map NormalPoint::getParams()
 {
-  std::map<QCString, QString> m = Point::getParams();
+  prop_map m = Point::getParams();
   m["implementation-type"] = mimp->type();
   mimp->writeParams( m, this );
   return m;
 }
 
-void NormalPoint::setParams( const std::map<QCString, QString>& m )
+void NormalPoint::setParams( const prop_map& m )
 {
   Point::setParams( m );
   if ( mimp ) mimp->unselectArgs( this );
   delete mimp;
-  std::map<QCString,QString>::const_iterator p = m.find("implementation-type");
+  prop_map::const_iterator p = m.find("implementation-type");
   if( p == m.end() )
   {
     kdError() << k_funcinfo << "error in file !" << endl;
@@ -175,14 +177,14 @@ void NormalPoint::setParams( const std::map<QCString, QString>& m )
   mimp->readParams( m, this );
 };
 
-void FixedPointImp::writeParams( std::map<QCString, QString>& m,
+void FixedPointImp::writeParams( Object::prop_map& m,
                                  NormalPoint* )
 {
   m["x"] = QString::number( pwwca.x );
   m["y"] = QString::number( pwwca.y );
 }
 
-void FixedPointImp::readParams( const std::map<QCString, QString>& m,
+void FixedPointImp::readParams( const Object::prop_map& m,
                                 NormalPoint* p )
 {
   bool ok = true;
@@ -203,12 +205,12 @@ ConstrainedPointImp::ConstrainedPointImp()
 {
 }
 
-void ConstrainedPointImp::calc( NormalPoint* p, const ScreenInfo& )
+void ConstrainedPointImp::calc( NormalPoint* p )
 {
   p->setCoord( mcurve->getPoint( mparam ) );
 }
 
-void ConstrainedPointImp::startMove( const Coordinate&, NormalPoint* )
+void ConstrainedPointImp::startMove( const Coordinate&, NormalPoint*, const ScreenInfo& )
 {
 }
 
@@ -221,13 +223,13 @@ void ConstrainedPointImp::stopMove( NormalPoint* )
 {
 }
 
-void ConstrainedPointImp::writeParams( std::map<QCString, QString>& m,
+void ConstrainedPointImp::writeParams( Object::prop_map& m,
                                        NormalPoint* )
 {
   m["param"] = QString::number( mparam );
 }
 
-void ConstrainedPointImp::readParams( const std::map<QCString, QString>& m,
+void ConstrainedPointImp::readParams( const Object::prop_map& m,
                                       NormalPoint* )
 {
   bool ok;
@@ -254,13 +256,13 @@ ConstrainedPointImp::ConstrainedPointImp( const ConstrainedPointImp& p,
   mcurve->addChild( np );
 }
 
-void NormalPoint::calc( const ScreenInfo& r )
+void NormalPoint::calc()
 {
   mvalid = true;
   Objects p = getParents();
   for ( Objects::iterator i = p.begin(); i != p.end(); ++i )
     mvalid &= (*i)->valid();
-  if ( mvalid ) mimp->calc( this, r );
+  if ( mvalid ) mimp->calc( this );
 }
 
 Objects NormalPoint::getParents() const
@@ -334,9 +336,9 @@ void NormalPoint::stopMove()
   mimp->stopMove( this );
 }
 
-void NormalPoint::startMove( const Coordinate& c )
+void NormalPoint::startMove( const Coordinate& c, const ScreenInfo& si )
 {
-  mimp->startMove( c, this );
+  mimp->startMove( c, this, si );
 }
 
 void NormalPoint::moveTo( const Coordinate& c )
@@ -520,10 +522,10 @@ void NormalPoint::setImp( NormalPointImp* i )
 
 NormalPoint* NormalPoint::sensiblePoint( const Coordinate& c,
                                          const KigDocument& d,
-                                         double fault )
+                                         const KigWidget& w )
 {
   NormalPoint* p = fixedPoint( c );
-  p->redefine( c, d, fault );
+  p->redefine( c, d, w );
   return p;
 }
 
@@ -537,16 +539,14 @@ const char* NormalPoint::sActionName()
   return "objects_new_normalpoint";
 }
 
-const QStringList NormalPoint::objectActions() const
+void NormalPoint::addActions( NormalModePopupObjects& popup )
 {
-  QStringList l;
-  l << i18n( "Redefine this point..." );
-  return l;
+  Point::addActions( popup );
+  popup.addNormalAction( NormalModePopupObjects::virtualActionsOffset + 10, i18n( "Redefine this point..." ) );
 }
 
-void NormalPoint::doAction( int which, KigDocument* d, KigWidget* v, NormalMode* m )
+void NormalPoint::doNormalAction( int which, KigDocument* d, KigWidget* v, NormalMode* m, const Coordinate& )
 {
-  assert( which == 0 );
+  assert( which == NormalModePopupObjects::virtualActionsOffset + 10 );
   d->setMode( new NormalPointRedefineMode( this, d, v, m ) );
-  return;
 }
