@@ -61,7 +61,7 @@ public:
   static NormalPoint* constrainedPoint( Curve* c, const Coordinate& c );
   // sensiblePoint() returns a new NormalPoint with an imp selected
   // with the same method as in redefine()...
-  static NormalPoint* sensiblePoint( const Coordinate& c, const KigDocument&, double fault );
+  static NormalPoint* sensiblePoint( const Coordinate& c, const KigDocument&, const KigWidget& w );
 
   virtual NormalPoint* toNormalPoint();
   virtual const NormalPoint* toNormalPoint() const;
@@ -79,10 +79,10 @@ public:
   // ConstrainedImp.., and otherwise returns a FixedImp...
   // fault is the argument we pass to KigDocument::whatAmIOn()...
   // you should still call calc() after this !
-  void redefine( const Coordinate& c, const KigDocument&, double fault );
+  void redefine( const Coordinate& c, const KigDocument&, const KigWidget& );
 
-  std::map<QCString, QString> getParams();
-  void setParams( const std::map<QCString, QString>& m );
+  prop_map getParams();
+  void setParams( const prop_map& m );
 
   virtual const QCString vFullTypeName() const;
   static const QCString sFullTypeName();
@@ -98,14 +98,14 @@ public:
 
   static KigMode* sConstructMode( Type*, KigDocument*, NormalMode* );
 
-  const QStringList objectActions() const;
-  void doAction( int which, KigDocument* d, KigWidget* v, NormalMode* m );
+  virtual void addActions( NormalModePopupObjects& );
+  virtual void doNormalAction( int which, KigDocument* d, KigWidget* v, NormalMode* m, const Coordinate& cp );
 
   virtual Objects getParents() const;
-  virtual void calc( const ScreenInfo& s );
+  virtual void calc();
 
   //moving
-  virtual void startMove( const Coordinate& c );
+  virtual void startMove( const Coordinate& c, const ScreenInfo& );
   virtual void moveTo( const Coordinate& c );
   virtual void stopMove();
 };
@@ -127,14 +127,14 @@ class NormalPointImp
   virtual const FixedPointImp* toFixed() const;
   virtual const ConstrainedPointImp* toConstrained() const;
 
-  virtual void startMove( const Coordinate& c, NormalPoint* p ) = 0;
+  virtual void startMove( const Coordinate& c, NormalPoint* p, const ScreenInfo& ) = 0;
   virtual void moveTo( const Coordinate& c, NormalPoint* p ) = 0;
   virtual void stopMove( NormalPoint* p ) = 0;
-  virtual void calc( NormalPoint* p, const ScreenInfo& s ) = 0;
+  virtual void calc( NormalPoint* p ) = 0;
 
   virtual QString type() = 0;
-  virtual void writeParams( std::map<QCString, QString>& m, NormalPoint* p ) = 0;
-  virtual void readParams( const std::map<QCString, QString>& m, NormalPoint* p ) = 0;
+  virtual void writeParams( Object::prop_map& m, NormalPoint* p ) = 0;
+  virtual void readParams( const Object::prop_map& m, NormalPoint* p ) = 0;
 
   virtual void setParents( const Objects& os, NormalPoint* p ) = 0;
   virtual void unselectArgs( NormalPoint* ) = 0;
@@ -164,15 +164,15 @@ public:
   void setCoord( const Coordinate& c );
   const Coordinate getCoord();
 
-  virtual void calc( NormalPoint* p, const ScreenInfo& r );
-  virtual void startMove( const Coordinate& c, NormalPoint* p );
+  virtual void calc( NormalPoint* p );
+  virtual void startMove( const Coordinate& c, NormalPoint* p, const ScreenInfo& );
   virtual void moveTo( const Coordinate& c, NormalPoint* p );
   virtual void stopMove( NormalPoint* p);
 
   virtual QString type();
   static QString sType();
-  virtual void writeParams( std::map<QCString, QString>& m, NormalPoint* p );
-  virtual void readParams( const std::map<QCString, QString>& m, NormalPoint* p );
+  virtual void writeParams( Object::prop_map& m, NormalPoint* p );
+  virtual void readParams( const Object::prop_map& m, NormalPoint* p );
 
   virtual Objects getParents();
 
@@ -207,15 +207,15 @@ public:
   void setP( const double p );
   double getP();
 
-  virtual void calc( NormalPoint* p, const ScreenInfo& s );
-  virtual void startMove( const Coordinate& c, NormalPoint* );
+  virtual void calc( NormalPoint* p );
+  virtual void startMove( const Coordinate& c, NormalPoint*, const ScreenInfo& );
   virtual void moveTo( const Coordinate& c, NormalPoint* );
   virtual void stopMove( NormalPoint* );
 
   virtual QString type();
   static QString sType();
-  virtual void writeParams( std::map<QCString, QString>& m, NormalPoint* p );
-  virtual void readParams( const std::map<QCString, QString>& m, NormalPoint* p );
+  virtual void writeParams( Object::prop_map& m, NormalPoint* p );
+  virtual void readParams( const Object::prop_map& m, NormalPoint* p );
 
   virtual void setParents( const Objects& os, NormalPoint* p );
   virtual void unselectArgs( NormalPoint* );
