@@ -20,13 +20,21 @@
 
 #include "object.h"
 
+#include "coordproppoint.h"
+#include "label.h"
+#include "property.h"
+
 #include "../misc/types.h"
 #include "../misc/type.h"
 #include "../modes/constructing.h"
+#include "../modes/popup.h"
 
 #include "../kig/kig_part.h"
+#include "../kig/kig_view.h"
 
 #include <klocale.h>
+#include <qpopupmenu.h>
+#include <qcursor.h>
 
 myvector<Type*> Object::sbuiltintypes;
 myvector<Type*> Object::susertypes;
@@ -64,24 +72,24 @@ Objects Object::getAllChildren() const
   return tmp;
 }
 
-std::map<QCString,QString> Object::getParams()
+Object::prop_map Object::getParams()
 {
-  std::map<QCString, QString> m;
+  prop_map m;
   m["color"] = mColor.name();
-  m["shown"] = QString::fromUtf8( mshown ? "true" : "false" );
+  m["shown"] = QString::fromLatin1( mshown ? "true" : "false" );
   return m;
 }
 
-void Object::setParams( const std::map<QCString,QString>& m )
+void Object::setParams( const prop_map& m )
 {
   {
-    std::map<QCString,QString>::const_iterator p = m.find("color");
+    prop_map::const_iterator p = m.find("color");
     if( p == m.end() ) mColor = Qt::blue;
     else mColor = QColor( p->second );
     assert( mColor.isValid() );
   };
   {
-    std::map<QCString,QString>::const_iterator p = m.find("shown");
+    prop_map::const_iterator p = m.find("shown");
     if( p != m.end() && p->second == QString::fromUtf8( "false" ) )
       mshown = false;
     else mshown = true;
@@ -104,7 +112,7 @@ const myvector<Type*>& Object::userTypes()
 }
 
 Object* Object::newObject( const QCString& type, const Objects& parents,
-                           const std::map<QCString, QString>& params )
+                           const prop_map& params )
 {
   return types().buildObject( type, parents, params );
 }
@@ -143,16 +151,6 @@ void Object::drawWrap(KigPainter& p, bool ss) const
   if ( mshown && mvalid ) draw(p,ss);
 }
 
-const QStringList Object::objectActions() const
-{
-  return QStringList();
-}
-
-void Object::doAction( int, KigDocument*, KigWidget*, NormalMode* )
-{
-  return;
-}
-
 void Object::addBuiltinType( Type* t )
 {
   stypes.addType( t );
@@ -224,3 +222,104 @@ void Object::setShown( bool in )
 {
   mshown = in;
 }
+
+void Object::addActions( NormalModePopupObjects& m )
+{
+  QPopupMenu* pm = new QPopupMenu( &m, "construct_coord_props_menu" );
+
+  bool content = false;         // true if we have content..
+
+  QCStringList s = properties();
+  for ( uint i = 0; i < numberOfProperties(); ++i )
+  {
+    Property p = property( i, m.widget() );
+    if ( p.type() == Property::Coord )
+    {
+      content = true;
+      QString str = i18n( s[i] );
+      uint id = pm->insertItem( str, i );
+      assert( id == i );
+    };
+  };
+
+  m.addPopupAction( 3849, i18n( "Construct the ..." ), pm );
+
+  pm = new QPopupMenu( &m, "construct_textlabels_menu" );
+  for ( uint i = 0; i < numberOfProperties(); ++i )
+  {
+    QString str = i18n( s[i] );
+    uint id = pm->insertItem( str, i );
+    assert( i == id );
+  };
+  m.addPopupAction( 3850, i18n( "Show the ..." ), pm );
+
+  return;
+}
+
+void Object::doNormalAction( int, KigDocument*, KigWidget*, NormalMode*, const Coordinate& )
+{
+  return;
+}
+
+void Object::doPopupAction( int popupid, int actionid, KigDocument* doc, KigWidget* w, NormalMode*, const Coordinate& cp )
+{
+  if( popupid == 3849 )
+  {
+    uint pid = static_cast<uint>( actionid );
+    assert( property( pid, *w ).type() == Property::Coord );
+    Object* o = new CoordinatePropertyPoint( this, pid );
+    o->calcForWidget( *w );
+    doc->addObject( o );
+    w->redrawScreen();
+  }
+  else if ( popupid == 3850 )
+  {
+    uint pid = static_cast<uint>( actionid );
+    TextLabel::propvect props;
+    props.push_back( TextLabelProperty( this, pid ) );
+    Object* o = new TextLabel( QString::fromLatin1( "%1" ), cp, props );
+    o->calcForWidget( *w );
+    doc->addObject( o );
+    w->redrawScreen();
+  }
+  else assert( false );
+}
+
+const QCStringList Object::properties() const
+{
+  QCStringList s;
+  s << I18N_NOOP( "Base Object Type" );
+  assert( s.size() == Object::numberOfProperties() );
+  return s;
+}
+
+const Property Object::property( uint which, const KigWidget& ) const
+{
+  assert( which == 0 );
+  return Property( vTBaseTypeName() );
+}
+
+const uint Object::numberOfProperties() const
+{
+  return 1;
+}
+
+void Object::calcForWidget( const KigWidget& )
+{
+  calc();
+}
+
+void Object::startMove( const Coordinate&, const ScreenInfo& )
+{
+  // default is that we don't move..
+}
+
+void Object::moveTo(const Coordinate&)
+{
+  // default is that we don't move..
+}
+
+void Object::stopMove()
+{
+  // default is that we don't move..
+}
