@@ -29,6 +29,8 @@
 #include <qnamespace.h>
 #include <qcolor.h>
 
+#include "property.h"
+
 #include "../misc/objects.h"
 
 class AbstractLine;
@@ -39,6 +41,7 @@ class Vector;
 class Ray;
 class Line;
 class Circle;
+class Conic;
 class Curve;
 class NormalPoint;
 class TextLabel;
@@ -54,6 +57,9 @@ class Rect;
 class NormalMode;
 class ScreenInfo;
 class StdConstructibleType;
+class NormalModePopupObjects;
+
+typedef QValueList<QCString> QCStringList;
 
 /**
  * Object is a base class representing all objects (e.g. points, lines etc.).
@@ -68,6 +74,8 @@ private:
   static myvector<Type*> susertypes;
   static Types stypes;
 public:
+  typedef std::map<QCString, QString> prop_map;
+
   // we have two types of types :)
   // 1 Builtin types: these are the C++ object types + perhaps in the
   //   future some macro types that we distribute along with Kig.
@@ -103,11 +111,11 @@ public:
   static const myvector<Type*>& builtinTypes();
   static const myvector<Type*>& userTypes();
   static Object* newObject( const QCString& type, const Objects& parents,
-                            const std::map<QCString, QString>& params );
+                            const prop_map& params );
 public:
   // if you want to use StdConstructionMode, you need a constructor
-  // like Object( const Objects& args ); See the functions wantArgs(),
-  // drawPrelim() and useText() for more information...
+  // like Object( const Objects& args ); See the functions sWantArgs(),
+  // sDrawPrelim() and sUseText() for more information...
   Object();
   Object( const Object& o );
   virtual ~Object() {};
@@ -118,6 +126,19 @@ public:
    */
   virtual Object* copy() = 0;
 
+  // Properties are a generic way to retrieve object information.
+  // They are mainly used for showing textlabels with information
+  // about an object ( e.g. This segment is %1 units long ).
+  // every object has a number of properties.
+  // the Object class itself defines some properties too..
+  virtual const uint numberOfProperties() const;
+  virtual const Property property( uint which, const KigWidget& w ) const;
+  // this gives a list of brief descriptions of the properties.  The
+  // names should be between I18N_NOOP(), and they should be ordered
+  // such that if one takes property( a ) gives you the property
+  // described by "properties()[a]".
+  virtual const QCStringList properties() const;
+
   // only object types that have "parameters" need this, a parameter
   // is something which you cannot calculate from your parents,
   // e.g. an independent point's params are its coordinates, a
@@ -125,8 +146,8 @@ public:
   // Objects that reimplement this should call Object::getParams() and
   // setParams() after you've handled your params.. --> to set params
   // common to all objects like the color...
-  virtual std::map<QCString,QString> getParams ();
-  virtual void setParams ( const std::map<QCString,QString>& );
+  virtual prop_map getParams ();
+  virtual void setParams ( const prop_map& );
 
   // getting types from this object: easier to type and supports
   // MacroObjectOne
@@ -136,6 +157,7 @@ public:
   virtual Ray* toRay() { return 0; };
   virtual Line* toLine() { return 0; };
   virtual Circle* toCircle() { return 0; };
+  virtual Conic* toConic() { return 0; };
   virtual Curve* toCurve() { return 0; };
   virtual NormalPoint* toNormalPoint() { return 0; };
   virtual TextLabel* toTextLabel() { return 0; };
@@ -148,6 +170,7 @@ public:
   virtual const Ray* toRay() const { return 0; };
   virtual const Line* toLine() const { return 0; };
   virtual const Circle* toCircle() const { return 0; };
+  virtual const Conic* toConic() const { return 0; };
   virtual const Curve* toCurve() const { return 0; };
   virtual const NormalPoint* toNormalPoint() const { return 0; };
   virtual const TextLabel* toTextLabel() const { return 0; };
@@ -231,7 +254,7 @@ public:
    * allowed_miss contains the maximum distance there may be between
    * o and your object...
    */
-  virtual bool contains ( const Coordinate& o, const double allowed_miss ) const = 0;
+  virtual bool contains ( const Coordinate& o, const ScreenInfo& si ) const = 0;
 
   /**
    * Is this object in rect r ?
@@ -262,26 +285,40 @@ public:
   // sos contains the objects that are being moved.
   // the point is where the cursor is,  check the point implementation for an
   // example
-  virtual void startMove(const Coordinate&) = 0;
-  virtual void moveTo(const Coordinate&) = 0;
-  virtual void stopMove() = 0;
+  virtual void startMove( const Coordinate&, const ScreenInfo& );
+  virtual void moveTo(const Coordinate&);
+  virtual void stopMove();
 
   /**
    * Informs the object that it ( or one of its parents ) has been
    * moved (or other situations), and that it should recalculate any
-   * of its variables.  showingRect is the rect that is currently
-   * showing.  Some objects need this ( e.g. Locus only wants points
-   * that are in the rect, and throws away the rest... )
+   * of its variables.  Some objects need extra information from
+   * KigDocument and KigWidget ( e.g. Locus keeps only the points that
+   * are visible on calcing, TextLabel needs the CoordinateSystem for
+   * showing Coordinate properties... ), but they only need this when
+   * they're being drawn, so they should ignore normal calc() calls,
+   * and only respond on calcForWidget() calls.  Note that they have
+   * to make sure that stuff like getPoint() and calls like
+   * AbstractLine::p1() return useful stuff after calc() is called.
+   * Normal calc() calls are used e.g. in the locus calc() function..
+   * The default calcForWidget() implementation just calls calc()..
    */
-  virtual void calc( const ScreenInfo& showingRect ) = 0;
+  virtual void calcForWidget( const KigWidget& widg );
+private:
+  virtual void calc() = 0;
+  // Objects needs to be able to call this function...
+  friend class Objects;
+public:
 
   /**
    * This is a list of object-specific actions that appears when a
    * popup menu for a single object is shown.  An example is
    * NormalPoint that has a "redefine" action...
+   * cp is the position where the popup menu appeared on screen..
    */
-  virtual const QStringList objectActions() const;
-  virtual void doAction( int which, KigDocument* d, KigWidget* v, NormalMode* m );
+  virtual void addActions( NormalModePopupObjects& );
+  virtual void doNormalAction( int which, KigDocument* d, KigWidget* v, NormalMode* m, const Coordinate& cp );
+  virtual void doPopupAction( int popupid, int actionid, KigDocument* d, KigWidget* w, NormalMode* m, const Coordinate& cp );
 
 protected:
   QColor mColor;
