@@ -43,12 +43,22 @@ public:
   static const QCString sBaseTypeName();
 
   // general members
-  virtual bool contains (const Coordinate& o, const double fault ) const;
+  virtual bool contains (const Coordinate& o, const ScreenInfo& si ) const;
   virtual void draw (KigPainter& p,bool showSelection = true) const;
   virtual bool inRect(const Rect& r) const;
 
   const Coordinate& getCoord() const;
 
+  virtual prop_map getParams ();
+  virtual void setParams ( const prop_map& );
+
+  virtual void addActions( NormalModePopupObjects& );
+  virtual void doPopupAction( int popupid, int actionid, KigDocument* d, KigWidget* w, NormalMode* m, const Coordinate& );
+
+  virtual const uint numberOfProperties() const;
+  virtual const Property property( uint which, const KigWidget& w ) const;
+  virtual const QCStringList properties() const;
+
 public:
   double getX() const;
   double getY() const;
@@ -56,7 +66,10 @@ public:
   void setY (const double inY);
 
 protected:
+  static void sDrawPrelimPoint( KigPainter& painter, const Coordinate& p );
+
   Coordinate mC;
+  int msize;
 };
 
 #endif // POINT_H
