@@ -44,9 +44,9 @@ Segment::~Segment()
 {
 }
 
-bool Segment::contains(const Coordinate& o, const double fault ) const
+bool Segment::contains(const Coordinate& o, const ScreenInfo& si ) const
 {
-  return isOnSegment( o, mpa->getCoord(), mpb->getCoord(), fault );
+  return isOnSegment( o, mpa->getCoord(), mpb->getCoord(), si.normalMiss() );
 }
 
 void Segment::draw(KigPainter& p, bool ss) const
@@ -77,12 +77,12 @@ QString Segment::sUseText( const Objects& os, const Object* o )
   return i18n( "Start point" );
 }
 
-void Segment::startMove(const Coordinate& p)
+void Segment::startMove(const Coordinate& p, const ScreenInfo& si )
 {
   pwwsm = p;
   assert( mpa && mpb );
-  mpa->startMove( p );
-  mpb->startMove( p );
+  mpa->startMove( p, si );
+  mpb->startMove( p, si );
 }
 
 void Segment::moveTo(const Coordinate& p)
@@ -95,7 +95,7 @@ void Segment::stopMove()
 {
 }
 
-void Segment::calc( const ScreenInfo& )
+void Segment::calc()
 {
   mvalid = mpa->valid() && mpb->valid();
 }
@@ -108,8 +108,8 @@ Coordinate Segment::getPoint(double param) const
 
 double Segment::getParam(const Coordinate& p) const
 {
-  Coordinate pt = calcPointOnPerpend(mpa->getCoord(), mpb->getCoord(), p);
-  pt = calcIntersectionPoint(mpa->getCoord(), mpb->getCoord(), p, pt);
+  Coordinate pt = calcPointOnPerpend( lineData(), p );
+  pt = calcIntersectionPoint( lineData(), LineData( p, pt ) );
   // if pt is over the end of the segment ( i.e. it's on the line
   // which the segment is a part of, but not of the segment itself..;
   // ) we set it to one of the end points of the segment...
@@ -235,3 +235,27 @@ const Coordinate Segment::p2() const
 {
   return mpb->getCoord();
 }
+
+const uint Segment::numberOfProperties() const
+{
+  return AbstractLine::numberOfProperties() + 1;
+}
+
+const Property Segment::property( uint which, const KigWidget& w ) const
+{
+  if ( which < AbstractLine::numberOfProperties() )
+    return AbstractLine::property( which, w );
+  if ( which == AbstractLine::numberOfProperties() )
+  {
+    return Property( ( p2() - p1() ).length() );
+  }
+  else assert( false );
+}
+
+const QCStringList Segment::properties() const
+{
+  QCStringList s = AbstractLine::properties();
+  s << I18N_NOOP( "Length" );
+  assert( s.size() == Segment::numberOfProperties() );
+  return s;
+}
