@@ -52,7 +52,7 @@ public:
   static const int sShortCut();
   static const char* sActionName();
 
-  bool contains (const Coordinate& o, const double fault ) const;
+  bool contains (const Coordinate& o, const ScreenInfo& si ) const;
   void draw ( KigPainter& p, bool showSelection ) const;
 
   bool inRect (const Rect&) const;
@@ -65,17 +65,22 @@ public:
   Objects getParents() const;
 
   // moving
-  void startMove(const Coordinate&);
+  void startMove(const Coordinate&, const ScreenInfo&);
   void moveTo(const Coordinate&);
   void stopMove();
 
-  void calc( const ScreenInfo& );
+  void calc();
 
   Coordinate getPoint (double param) const;
   double getParam (const Coordinate&) const;
 
   const Coordinate p1() const;
   const Coordinate p2() const;
+
+  const uint numberOfProperties() const;
+  const Property property( uint which, const KigWidget& w ) const;
+  const QCStringList properties() const;
+
 protected:
   Point* mpa, *mpb;
   Coordinate pwwsm; // point where we started moving
